import { addons } from '@storybook/addons';
import { create } from '@storybook/theming/create';


// brandImage fix for known SB webpack issue where SVGs aren't served locally when imported.
const logoAsPath = 'data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTkwIiBoZWlnaHQ9IjMyIiB2aWV3Qm94PSIwIDAgMTkwIDMy\
IiBmaWxsPSJub25lIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgo8cGF0aCBkPSJNMTYgMzEuMTg2NEMyNC4zODczIDMxLj\
E4NjQgMzEuMTg2NSAyNC4zODcyIDMxLjE4NjUgMTZDMzEuMTg2NSA3LjYxMjc2IDI0LjM4NzMgMC44MTM1NiAxNiAwLjgxMzU2QzcuNjEyOCAw\
LjgxMzU2IDAuODEzNTk5IDcuNjEyNzYgMC44MTM1OTkgMTZDMC44MTM1OTkgMjQuMzg3MiA3LjYxMjggMzEuMTg2NCAxNiAzMS4xODY0WiIgZm\
lsbD0id2hpdGUiLz4KPHBhdGggZD0iTTE2IDBDNy4xNjM0NCAwIDAgNy4xNjM0NCAwIDE2QzAgMjQuODM2NiA3LjE2MzQ0IDMyIDE2IDMyQzI0\
LjgzNjYgMzIgMzIgMjQuODM2NiAzMiAxNkMzMiA3LjE2MzQ0IDI0LjgzNjYgMCAxNiAwWk0xNiAxLjYyNzEyQzIzLjkzNzkgMS42MjcxMiAzMC\
4zNzI5IDguMDYyMDggMzAuMzcyOSAxNkMzMC4zNzI5IDIzLjkzNzkgMjMuOTM3OSAzMC4zNzI5IDE2IDMwLjM3MjlDOC4wNjIwOCAzMC4zNzI5\
IDEuNjI3MTIgMjMuOTM3OSAxLjYyNzEyIDE2QzEuNjI3MTIgOC4wNjIwOCA4LjA2MjA4IDEuNjI3MTIgMTYgMS42MjcxMloiIGZpbGw9IiM0MD\
AwQkYiLz4KPHBhdGggZmlsbC1ydWxlPSJldmVub2RkIiBjbGlwLXJ1bGU9ImV2ZW5vZGQiIGQ9Ik0xNi4xODA3IDQuNjEwMTdDMjIuNDcxMiA0\
LjYxMDE3IDI3LjU3MDYgOS43MDk1NyAyNy41NzA2IDE2QzI3LjU3MDYgMjIuMjkwNCAyMi40NzEyIDI3LjM4OTggMTYuMTgwNyAyNy4zODk4Qz\
kuODkwMjkgMjcuMzg5OCA0Ljc5MDg5IDIyLjI5MDQgNC43OTA4OSAxNkM0Ljc5MDg5IDE0LjQ2MjcgNS4wOTU0NyAxMi45OTY1IDUuNjQ3NTgg\
MTEuNjU4NEM2LjQ1MzczIDEyLjc1NjIgNy43NTM3NyAxMy40Njg5IDkuMjIwMjcgMTMuNDY4OUMxMS42NjY2IDEzLjQ2ODkgMTMuNjQ5NiAxMS\
40ODU4IDEzLjY0OTYgOS4wMzk1NUMxMy42NDk2IDcuNTczMDUgMTIuOTM3IDYuMjczMDEgMTEuODM5MSA1LjQ2Njg3QzEzLjE3NzIgNC45MTQ3\
NSAxNC42NDM0IDQuNjEwMTcgMTYuMTgwNyA0LjYxMDE3WiIgZmlsbD0idXJsKCNwYWludDBfbGluZWFyKSIvPgo8cGF0aCBkPSJNNDUuNTM1Mi\
AyNVY2LjY4MDY2SDQyLjI1OThWMjVINDUuNTM1MlpNNDkuNzI0NiAyNUg1Mi44NzNWMTYuOTEzMUM1Mi44NzMgMTQuODMxMSA1NC4wNTM3IDEz\
LjUyMzQgNTUuOTMyNiAxMy41MjM0QzU3Ljg0OTYgMTMuNTIzNCA1OC43MzgzIDE0LjYwMjUgNTguNzM4MyAxNi43NjA3VjI1SDYxLjg4NjdWMT\
YuMDI0NEM2MS44ODY3IDEyLjcyMzYgNjAuMTk4MiAxMC44NTc0IDU3LjEwMDYgMTAuODU3NEM1NS4wMzEyIDEwLjg1NzQgNTMuNjM0OCAxMS43\
OTY5IDUyLjk3NDYgMTMuMzQ1N0g1Mi43NTg4VjExLjEyNEg0OS43MjQ2VjI1Wk02NS4zMDE4IDE1LjA4NUM2NS4zMDE4IDE3LjE2NyA2Ni41NT\
g2IDE4LjM4NTcgNjkuMjI0NiAxOC45OTUxTDcxLjY4NzUgMTkuNTY2NEM3My4wMDc4IDE5Ljg3MTEgNzMuNjA0NSAyMC4zNzg5IDczLjYwNDUg\
MjEuMTY2QzczLjYwNDUgMjIuMjE5NyA3Mi41IDIyLjk0MzQgNzAuOTEzMSAyMi45NDM0QzY5LjMzODkgMjIuOTQzNCA2OC4zNjEzIDIyLjMwOD\
YgNjguMDU2NiAyMS4yODAzSDY0Ljk0NjNDNjUuMTg3NSAyMy43ODEyIDY3LjM3MTEgMjUuMjc5MyA3MC44MzY5IDI1LjI3OTNDNzQuMzAyNyAy\
NS4yNzkzIDc2Ljc1MjkgMjMuNTE0NiA3Ni43NTI5IDIwLjg2MTNDNzYuNzUyOSAxOC44MTc0IDc1LjUyMTUgMTcuNjg3NSA3Mi44NjgyIDE3Lj\
A3ODFMNzAuNDE4IDE2LjUzMjJDNjkuMDIxNSAxNi4yMDIxIDY4LjM2MTMgMTUuNzA3IDY4LjM2MTMgMTQuOTE5OUM2OC4zNjEzIDEzLjg5MTYg\
NjkuNDQwNCAxMy4xOTM0IDcwLjg3NSAxMy4xOTM0QzcyLjM0NzcgMTMuMTkzNCA3My4yNzQ0IDEzLjgyODEgNzMuNTAyOSAxNC44MDU3SDc2Lj\
Q2MDlDNzYuMjMyNCAxMi4zMDQ3IDc0LjE2MzEgMTAuODU3NCA3MC44NjIzIDEwLjg1NzRDNjcuNTg2OSAxMC44NTc0IDY1LjMwMTggMTIuNTk2\
NyA2NS4zMDE4IDE1LjA4NVpNODUuOTMxNiAyNS4yNzkzQzkwLjA4MyAyNS4yNzkzIDkyLjYwOTQgMjIuNTYyNSA5Mi42MDk0IDE4LjA1NTdDOT\
IuNjA5NCAxMy41NzQyIDkwLjA3MDMgMTAuODU3NCA4NS45MzE2IDEwLjg1NzRDODEuODA1NyAxMC44NTc0IDc5LjI1MzkgMTMuNTg2OSA3OS4y\
NTM5IDE4LjA1NTdDNzkuMjUzOSAyMi41NjI1IDgxLjc2NzYgMjUuMjc5MyA4NS45MzE2IDI1LjI3OTNaTTg1LjkzMTYgMjIuNzAyMUM4My43Mz\
U0IDIyLjcwMjEgODIuNDc4NSAyMS4wMDEgODIuNDc4NSAxOC4wNjg0QzgyLjQ3ODUgMTUuMTM1NyA4My43MzU0IDEzLjQzNDYgODUuOTMxNiAx\
My40MzQ2Qzg4LjExNTIgMTMuNDM0NiA4OS4zNzIxIDE1LjEzNTcgODkuMzcyMSAxOC4wNjg0Qzg5LjM3MjEgMjEuMDAxIDg4LjEyNzkgMjIuNz\
AyMSA4NS45MzE2IDIyLjcwMjFaTTk1Ljc4MzIgMjVIOTguOTMxNlYxNi41NTc2Qzk4LjkzMTYgMTQuODMxMSAxMDAuMDg3IDEzLjUyMzQgMTAx\
LjY0OCAxMy41MjM0QzEwMy4xOTcgMTMuNTIzNCAxMDQuMTYyIDE0LjQ2MjkgMTA0LjE2MiAxNS45OTlWMjVIMTA3LjIyMlYxNi4zMjkxQzEwNy\
4yMjIgMTQuNzQyMiAxMDguMzAxIDEzLjUyMzQgMTA5LjkzOCAxMy41MjM0QzExMS42MjcgMTMuNTIzNCAxMTIuNDc4IDE0LjQyNDggMTEyLjQ3\
OCAxNi4yMjc1VjI1SDExNS42MTNWMTUuNDUzMUMxMTUuNjEzIDEyLjU3MTMgMTEzLjkzOCAxMC44NTc0IDExMS4xNTcgMTAuODU3NEMxMDkuMj\
I4IDEwLjg1NzQgMTA3LjYyOCAxMS44NDc3IDEwNi45NDIgMTMuMzU4NEgxMDYuNzI3QzEwNi4xNDMgMTEuODIyMyAxMDQuODEgMTAuODU3NCAx\
MDIuODkzIDEwLjg1NzRDMTAxLjA1MiAxMC44NTc0IDk5LjYyOTkgMTEuNzk2OSA5OS4wMzMyIDEzLjM1ODRIOTguODE3NFYxMS4xMjRIOTUuNz\
gzMlYyNVpNMTE5LjM0NiAyNUgxMjIuNDk0VjE2LjkxMzFDMTIyLjQ5NCAxNC44MzExIDEyMy42NzUgMTMuNTIzNCAxMjUuNTU0IDEzLjUyMzRD\
MTI3LjQ3MSAxMy41MjM0IDEyOC4zNTkgMTQuNjAyNSAxMjguMzU5IDE2Ljc2MDdWMjVIMTMxLjUwOFYxNi4wMjQ0QzEzMS41MDggMTIuNzIzNi\
AxMjkuODE5IDEwLjg1NzQgMTI2LjcyMiAxMC44NTc0QzEyNC42NTIgMTAuODU3NCAxMjMuMjU2IDExLjc5NjkgMTIyLjU5NiAxMy4zNDU3SDEy\
Mi4zOFYxMS4xMjRIMTE5LjM0NlYyNVpNMTM2Ljg0IDguODAwNzhDMTM3Ljg4MSA4LjgwMDc4IDEzOC43MzEgNy45NzU1OSAxMzguNzMxIDYuOT\
M0NTdDMTM4LjczMSA1LjkwNjI1IDEzNy44ODEgNS4wNjgzNiAxMzYuODQgNS4wNjgzNkMxMzUuODEyIDUuMDY4MzYgMTM0Ljk2MSA1LjkwNjI1\
IDEzNC45NjEgNi45MzQ1N0MxMzQuOTYxIDcuOTc1NTkgMTM1LjgxMiA4LjgwMDc4IDEzNi44NCA4LjgwMDc4Wk0xMzUuMjc4IDI1SDEzOC40MT\
RWMTEuMTI0SDEzNS4yNzhWMjVaTTE0Ni4xNDYgMjUuMjI4NUMxNDcuOTYxIDI1LjIyODUgMTQ5LjQ4NCAyNC40NDE0IDE1MC4yNTkgMjMuMDk1\
N0gxNTAuNDc1VjI1SDE1My41MDlWMTUuNTE2NkMxNTMuNTA5IDEyLjU4NCAxNTEuNTAzIDEwLjg1NzQgMTQ3LjkzNiAxMC44NTc0QzE0NC42Mz\
UgMTAuODU3NCAxNDIuMzM3IDEyLjQwNjIgMTQyLjA4MyAxNC44MzExSDE0NS4wNTRDMTQ1LjM0NiAxMy44Nzg5IDE0Ni4zMzYgMTMuMzU4NCAx\
NDcuNzgzIDEzLjM1ODRDMTQ5LjQ4NCAxMy4zNTg0IDE1MC4zOTggMTQuMTMyOCAxNTAuMzk4IDE1LjUxNjZWMTYuNzFMMTQ2LjgxOCAxNi45Mj\
U4QzE0My40NDEgMTcuMTE2MiAxNDEuNTUgMTguNTc2MiAxNDEuNTUgMjEuMDY0NUMxNDEuNTUgMjMuNjAzNSAxNDMuNDY3IDI1LjIyODUgMTQ2\
LjE0NiAyNS4yMjg1Wk0xNDcuMDcyIDIyLjgwMzdDMTQ1LjY3NiAyMi44MDM3IDE0NC42NzMgMjIuMTA1NSAxNDQuNjczIDIwLjkxMjFDMTQ0Lj\
Y3MyAxOS43NTY4IDE0NS40OTggMTkuMTA5NCAxNDcuMjYzIDE4Ljk5NTFMMTUwLjM5OCAxOC43NzkzVjE5LjkwOTJDMTUwLjM5OCAyMS41NTk2\
IDE0OC45NzcgMjIuODAzNyAxNDcuMDcyIDIyLjgwMzdaTTE2Ny44MjkgNi42ODA2NkgxNjQuNTU0VjE4LjY5MDRDMTY0LjU1NCAyMi42ODk1ID\
E2Ny40NDggMjUuNDU3IDE3Mi4wODIgMjUuNDU3QzE3Ni43MTYgMjUuNDU3IDE3OS42MSAyMi42ODk1IDE3OS42MSAxOC42OTA0VjYuNjgwNjZI\
MTc2LjMzNVYxOC4zOTg0QzE3Ni4zMzUgMjAuODk5NCAxNzQuNzk5IDIyLjYwMDYgMTcyLjA4MiAyMi42MDA2QzE2OS4zNjUgMjIuNjAwNiAxNj\
cuODI5IDIwLjg5OTQgMTY3LjgyOSAxOC4zOTg0VjYuNjgwNjZaTTE4Ny4zOTMgMjVWNi42ODA2NkgxODQuMTE3VjI1SDE4Ny4zOTNaIiBmaWxs\
PSJibGFjayIvPgo8ZGVmcz4KPGxpbmVhckdyYWRpZW50IGlkPSJwYWludDBfbGluZWFyIiB4MT0iMTYuMTgwNyIgeTE9IjI3LjM4OTgiIHgyPS\
IxNi4xODA3IiB5Mj0iNC42MTAxNyIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiPgo8c3RvcCBzdG9wLWNvbG9yPSIjNzQwMEUxIi8+\
CjxzdG9wIG9mZnNldD0iMSIgc3RvcC1jb2xvcj0iIzQwMDBCRiIvPgo8L2xpbmVhckdyYWRpZW50Pgo8L2RlZnM+Cjwvc3ZnPgo=';

addons.setConfig({
  theme: create({
    base: 'light',
    colorPrimary: 'rgba(51, 52, 71, 1)',
    colorSecondary: 'rgba(64, 0, 191, 1)',
    brandImage: logoAsPath,
    appBg: 'white',
    appContentBg: 'rgba(240, 240, 240, 1)',
    appBorderColor: 'rgba(240, 240, 240, 1)',
    appBorderRadius: 3,
    brandUrl: 'https://insomnia.rest',
    mainFill: 'rgba(64, 0, 191, 1)',
    mainTextColor: 'rgba(64, 0, 191, 1)',
  }),
});
